@@ -8,15 +8,9 @@ pub struct LineWidth {
     pub value: f32,
 }
 
-/// Line color
-#[derive(Debug, Clone, Copy, PartialEq)]
+/// Line width
+#[derive(Debug, Clone, Copy, PartialEq, Default)]
 pub struct LineColor {
-    /// The line color
-    pub value: Srgba,
-}
-
-impl Default for LineColor {
-    fn default() -> Self {
-        Self { value: Srgba::new(1.0, 1.0, 1.0, 1.0) }
-    }
+    /// The line width
+    pub value: RGBA,
 }
