@@ -9,4 +9,4 @@ mod points;
 
 pub use color::RGBA;
 pub use lines::{LineColor, LineWidth};
-pub use points::PointSize;
+pub use points::{PointColor, PointSize};
